﻿using Hotline.Application.Snapshot;
using Hotline.Share.Dtos;
using Hotline.Share.Dtos.Article;
using Hotline.Share.Dtos.Snapshot;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;

namespace Hotline.Api.Controllers.Snapshot
{
    /// <summary>
    /// 随手拍接口
    /// </summary>
    public class SnapshotController : BaseController
    {
        private readonly ISnapshotApplication _snapshotApplication;

        public SnapshotController(ISnapshotApplication snapshotApplication)
        {
            _snapshotApplication = snapshotApplication;
        }

        /// <summary>
        /// 获取小程序公告列表
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpGet("bulletions")]
        [AllowAnonymous]
        public virtual async Task<IReadOnlyList<BulletinOutDto>> QueryBulletinsAsync([FromQuery] BulletinInDto dto)
            => await _snapshotApplication.GetBulletinsAsync(dto);

        /// <summary>
        /// 公告详情
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        [HttpGet("bulletions/{id}")]
        [AllowAnonymous]
        public virtual async Task<BulletinOutDto> QueryBulletionsDetailAsync([FromQuery] string id)
            => await _snapshotApplication.GetBulletinsDetailAsync(id);

        /// <summary>
        /// 获取用户页面数据
        /// </summary>
        /// <returns></returns>
        [AllowAnonymous]
        [HttpGet("user")]
        public virtual async Task<SnapshotUserInfoOutDto> GetUserInfo()
            => await _snapshotApplication.GetSnapshotUserInfoAsync();

        /// <summary>
        /// 获取我提交的线索列表
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpGet("order")]
        public virtual async Task<PagedDto<OrderOutDto>> QueryOrderListAsync([FromQuery] OrderInDto dto)
            => await _snapshotApplication.GetSnapshotOrdersAsync(dto);

        /// <summary>
        /// 获取我提交的线索详情
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        [HttpGet("order/{id}")]
        public virtual async Task<OrderDetailOutDto> QueryOrderListAsync([FromQuery] string id)
            => await _snapshotApplication.GetSnapshotOrderDetailAsync(id);

        /// <summary>
        /// 统计红包金额, 每月的总金额
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpGet("redpack")]
        public virtual async Task<IReadOnlyList<RedPackDateOutDto>> QueryRedPackDateAsync([FromQuery] RedPackDateInDto dto)
            => await _snapshotApplication.GetRedPackDateAsync(dto);

        /// <summary>
        /// 获取当月详细红包列表
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpGet("redpack/month")]
        public virtual async Task<PagedDto<RedPackOutDto>> QueryRedPackDateAsync([FromQuery] RedPacksInDto dto)
            => await _snapshotApplication.GetRedPacksAsync(dto);
    }
}
